********************************
* Prepared by Andrea Locatelli *
* This version 29 Dec, 01:33   *
********************************

* READ ME:
* Run this file after running "merging file.do"
* This will fix some basic problems of the data

* Open the dataset

use "C:\data\full_dataset.dta", clear

***********************************
* Fix the dates of the interviews *
***********************************

quietly recode monthv2 (0/12=.)  if  dayv2==0
quietly recode yearv2 (0/2010=.)  if  dayv2==0
quietly recode monthv2 (0/12=.)  if  dayv2==.
quietly recode yearv2 (0/2010=.)  if  dayv2==.
quietly recode dayv2 (0=.)

quietly recode monthv3 (0/12=.)  if  dayv3==0
quietly recode yearv3 (0/2010=.)  if  dayv3==0
quietly recode monthv3 (0/12=.)  if  dayv3==.
quietly recode yearv3 (0/2010=.)  if  dayv3==.
quietly recode dayv3 (0=.)

***********************************
* Turn all unexpected 0s into '.' *
* So we can compute means & var's *
***********************************

* qh7 admits 0 since it is hh member's age
* rh12 admits 0 since it is # days of school missed
* rh16 admits 0 since it is # days of school missed
* q101 admits 0 since it is responder's age
* q104 admits 0 since it is completed grade at a level
* q116 admits 0 if there are no sleeping rooms
* q122 admits 0 if respondent travels 0 times/months outside gash barka

quietly recode village_number-qh6  qh8-rh11  rh13-rh15  q102-q103  q106-q116  q117-q121  q123-q203  (0=.)

* q203 asks if youd would be willing to pay for a net
* q204 asks how much youd would be willing to pay for a net
* So, if you are willing to pay, q204 must be>0

quietly recode q204 (0=999) if q203==1
quietly recode q203 (1=2) if q204==999
quietly recode q204 (999=.) 

* q206 admits 0 if hh has no nets
* q209 admits 0 if net was obtained in past month
* q213 admits 0 if net was soaked/dipped in past month
* q224 admits 0 if DDT was sprayed in past month
* q233-q235 admit 0

quietly recode q205  q2071-q2084  q2101-q2124  q2141-q223  q226-q232  (0=.)

quietly recode q301-q308  q311-q303b  (0=.)

quietly recode q4011-q4014  q4031-q4034  q4061-q4074  q4131-q4134  q4151-q4154  (0=.)

* In the consumption section: yes/no are coded as 1/0 instead of 1/2
* Since interviewers were used to coding them as 1/2, we have some 2
* I want to quietly recode those 2 to 0.

quietly recode  q501a-q501g  q502a-q502g   q504a-q504h   q506-q507   q508a-q508j   q509a-q509j     (2=1)

save, replace 

* ############################################
* ############################################
