log using "C:\data\log_all.log", replace

********************************
* Prepared by Andrea Locatelli *
* This version 25 Jan @ 19.53  *
********************************

* README:
* run only this DO file

do "C:\data\merging  file.do"

sort  village_number household_number lineno
set more off

**********************************

 **       *
*  *     **
*  *    * *
*  *      *
*  * ***  *
*  *      *
 **      ***

* MAKE DUMMIES 0/1:
* To make yes/no asnwers easier to interprete, quietly recode yes/no from 1/2 to 1/0
* In this way their mean will be the % of 'yes', and [1-mean] = % of 'no'.

quietly recode  qh5 qh6 qh9  rh10 rh11 rh15 (2=0)
quietly recode  q102 q106 q111*  q119*  q120 q121  q123 q124 (2=0)
quietly recode  q201- q205 q207*  q211*  q214* q215_* q219 q220 q223 q226 q229- q231 (2=0)
quietly recode  q301 q308 q311 q312 q313 q315 (2=0)
quietly recode  q403* q406* q4071-q4074 q413* (2=0)
quietly recode  q500 (2=0)

**********************************

***   **  *   *
*  * *  *  * *
*  * ****   *
*  * *  *   *
* *  *  *   *

g date1=dayv1
g date2=dayv2
g date3=dayv3
g datef=dayvf

label var date1 "date of 1st visit"
label var date2 "date of 2nd visit"
label var date3 "date of 3rd visit"
label var datef "date of final visit"

foreach x of varlist date1 date2 date3 datef{
move `x'  interviewer_coded_name
}

* convert the dates in STATA format
*
*	01-Jan-1960				
*	18171	01-Oct-2009				
*	18172	02-Oct-2009				
*	18173	03-Oct-2009				
*	18174	04-Oct-2009		18174	04-Oct-2009	ok
*	18175	05-Oct-2009		18175	05-Oct-2009	ok
*	18176	06-Oct-2009		18176	06-Oct-2009	ok
*	18177	07-Oct-2009		18177	07-Oct-2009	ok
*	18178	08-Oct-2009		18178	08-Oct-2009	ok
*	18179	09-Oct-2009		18179	09-Oct-2009	ok
*	18180	10-Oct-2009		18180	10-Oct-2009	ok
*	18181	11-Oct-2009		18181	11-Oct-2009	ok
*	18182	12-Oct-2009		18182	12-Oct-2009	ok
*	18183	13-Oct-2009		18183	13-Oct-2009	ok
*	18184	14-Oct-2009		18184	14-Oct-2009	ok
*	18185	15-Oct-2009		18185	15-Oct-2009	ok
*	18186	16-Oct-2009				
*	18187	17-Oct-2009				
*	18188	18-Oct-2009				
*	18189	19-Oct-2009				
*	18190	20-Oct-2009				
*	18191	21-Oct-2009				
*	18192	22-Oct-2009				
*	18193	23-Oct-2009				
*	18194	24-Oct-2009				
*	18195	25-Oct-2009				

quietly recode date1 (4=18174) (5=18175) (6=18176) (7=18177) (8=18178) (9=18179) (10=18180) (11=18181) (12=18182) (13=18183) (14=18184) (15=18185)
quietly recode date2 (4=18174) (5=18175) (6=18176) (7=18177) (8=18178) (9=18179) (10=18180) (11=18181) (12=18182) (13=18183) (14=18184) (15=18185)
quietly recode date3 (4=18174) (5=18175) (6=18176) (7=18177) (8=18178) (9=18179) (10=18180) (11=18181) (12=18182) (13=18183) (14=18184) (15=18185)
quietly recode datef (4=18174) (5=18175) (6=18176) (7=18177) (8=18178) (9=18179) (10=18180) (11=18181) (12=18182) (13=18183) (14=18184) (15=18185)

format date1-datef  %td

* check
tab1 date1-datef
* ok

drop  dayv1- yearvf

**********************************

  *
 **
* *
  *
  *
  *
 ***

* PART OF SECTION #1 IS ONLY AIMED FOR THE RESPONDENT SO WE SHOULD APPEND THOSE ANSWERS TO RESPONDENTS ONLY

foreach x of varlist  q101- q108 q120 q121 q122 q123 q124{
quietly replace `x'= . if hh_roaster_line_number!= lineno &  hh_roaster_line_number!=.
}

**********************************

 ***
*   *
   *
  *
 *
*
*****

* PART OF SECTION #2 IS ONLY AIMED FOR THE RESPONDENT SO WE SHOULD APPEND THOSE ANSWERS TO RESPONDENTS ONLY

foreach x of varlist   q202- q205 q217- q222 q226 q231 q232- q232f q233{
quietly replace `x'= . if hh_roaster_line_number!= lineno &  hh_roaster_line_number!=.
}

***********
* fix 217 *
***********

g q217i=q217
g q217ii=q217
g q217iii=q217
g q217iv=q217
g q217v=q217

tostring  q217i- q217v, replace

foreach x of varlist q217i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q217ii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q217iii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q217iv{
quietly replace `x'= substr(`x',4,1)
}

foreach x of varlist q217v{
quietly replace `x'= substr(`x',5,1)
}

* to check you can use:
* list  q217  q217i- q217v if  q217!=.
* ok!

destring  q217i- q217v, replace

*sort
foreach y of varlist q217i- q217v{
move `y' q218
}

*label
foreach y of varlist q217i- q217v{
label var `y' "mentioned reason for respondent using a bed net"
}

drop q217

***********
* fix 218 *
***********

g q218i=q218
g q218ii=q218

tostring  q218i- q218ii, replace

foreach x of varlist q218i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q218ii{
quietly replace `x'= substr(`x',2,1)
}

* to check you can use:
* list  q218  q218i- q218vi if  q218!=.
* ok!

destring  q218i- q218ii, replace

*sort
foreach y of varlist q218i- q218ii{
move `y' q219
}

*label
foreach y of varlist q218i- q218ii{
label var `y' "mentioned frequency with which respondent uses a bed net"
}

drop q218

***********
* fix 221 *
***********

g q221i=q221
g q221ii=q221
g q221iii=q221
g q221iv=q221
g q221v=q221
g q221vi=q221

tostring  q221i- q221vi, replace

foreach x of varlist q221i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q221ii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q221iii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q221iv{
quietly replace `x'= substr(`x',4,1)
}

foreach x of varlist q221v{
quietly replace `x'= substr(`x',5,1)
}

foreach x of varlist q221vi{
quietly replace `x'= substr(`x',6,1)
}

* to check you can use:
* list  q221  q221i- q221vi if  q221!=.
* ok!

destring  q221i- q221vi, replace

*sort
foreach y of varlist q221i- q221vi{
move `y' q222
}

*label
foreach y of varlist q221i- q221vi{
label var `y' "mentioned way how respondent tries to stop mosquitoes from biting him/her"
}

drop q221

***********
* fix 222 *
***********

g q222i=q222
g q222ii=q222
g q222iii=q222

tostring  q222i- q222iii, replace

foreach x of varlist q222i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q222ii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q222iii{
quietly replace `x'= substr(`x',3,1)
}

* to check you can use:
* list  q222  q222i- q222iii if  q222!=.
* ok!

destring  q222i- q222iii, replace

*sort
foreach y of varlist q222i- q222iii{
move `y' q223
}

*label
foreach y of varlist q222i- q222iii{
label var `y' "mentioned time of day when mosquitoes bite the most"                                         
}	

drop q222


***********
* fix 232 *
***********

g q232i=q232
g q232ii=q232

tostring  q232i- q232ii, replace

foreach x of varlist q232i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q232ii{
quietly replace `x'= substr(`x',2,1)
}

* to check you can use:
* list  q232  q232i- q232ii if  q232!=.
* ok!

destring  q232i- q232ii, replace

*sort
foreach y of varlist q232i- q232ii{
move `y' q233
}

*label
foreach y of varlist q232i- q232ii{
label var `y' "mentioned task performed in enviromental mgmt in village in past 6 months"                                         
}

drop q232


**********************************

 ***
*   *
    *
 ***
    *
*   *
 ***

* SECTION #3 IS ONLY AIMED FOR THE RESPONDENT SO WE SHOULD APPEND ANSWERS TO RESPONDENTS ONLY

foreach x of varlist  q301-q308  q311-q315a{
quietly replace `x'= . if hh_roaster_line_number!= lineno &  hh_roaster_line_number!=.
}

quietly replace q309 = "." if  hh_roaster_line_number!= lineno &  hh_roaster_line_number!=.

***********
* fix 302 *
***********

tostring q302, replace

* iteration 1

quietly replace q302 = "A" if q302 == "10"
quietly replace q302 = "B" if q302 == "11"
quietly replace q302 = "C" if q302 == "98"
quietly replace q302 = "D" if q302 == "96"

quietly replace q302 = "D15" if q302 == "9615"

g q302i=q302
quietly replace q302i= substr(q302i,1,1)

g x302 = q302

* iteration 2

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302ii=x
quietly replace q302ii= substr(x,1,1)

* iteration 3

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302iii=x
quietly replace q302iii= substr(x,1,1)
 
* iteration 4

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302iv=x
quietly replace q302iv= substr(x,1,1)

* iteration 5

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302v=x
quietly replace q302v= substr(x,1,1)

* iteration 6

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302vi=x
quietly replace q302vi= substr(x,1,1)

* iteration 7

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "98"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^98")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q302vii=x
quietly replace q302vii= substr(x,1,1)

* quietly replace A,B,C,D, with 10,11,98,96

foreach x of varlist q302 q302i q302ii q302iii q302iv q302v  q302vi q302vii{
quietly replace `x' = "10" if `x' == "A"
quietly replace `x' = "11" if `x' == "B"
quietly replace `x' = "98" if `x' == "C"
quietly replace `x' = "96" if `x' == "D"
}

* check
* list q302 q302i q302ii q302iii q302iv q302v  q302vi q302vii if q302!="."

drop x

*sort

foreach y of varlist  q302i- q302vii {
move `y' q303
}

*label
foreach y of varlist q302i- q302vii {
label var `y' "mentioned malaria vector"
}

drop q302


***********
* fix 303 *
***********

* change 98 into a single digit eg 7
quietly recode q303 (98=7)

g q303i=q303
g q303ii=q303

tostring  q303i- q303ii, replace

foreach x of varlist q303i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q303ii{
quietly replace `x'= substr(`x',2,1)
}

destring  q303i- q303ii, replace

quietly recode q303i (7=98)

* to check you can use:
* list  q303  q303i- q303ii if  q303!=.
* ok!

*sort
foreach y of varlist q303i- q303ii{
move `y' q303a
}

*label
foreach y of varlist q303i- q303ii{
label var `y' "mentioned option for who is most affected by malaria"
}

drop q303

************
* fix 303a *
************

* change 98 into a single digit eg 7
quietly recode q303a (98=7)

g q303ai=q303a
g q303aii=q303a

tostring  q303ai- q303aii, replace

foreach x of varlist q303ai{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q303aii{
quietly replace `x'= substr(`x',2,1)
}

destring  q303ai- q303aii, replace

quietly recode q303ai (7=98)

* to check you can use:
* list  q303a  q303ai- q303aii if  q303a!=.
* ok!

*sort
foreach y of varlist q303ai- q303aii{
move `y' q303b
}

*label
foreach y of varlist q303ai- q303aii{
label var `y' "mentioned option for who is most affected by malaria"
}

drop q303a

***********#########################################################################
* fix 306 *#this variable should contain date of last malaria. Solomon will fix it #
***********#########################################################################

***********
* fix 307 *
***********

tostring q307, replace format(%15.0g)

* 12 was not expected, it must have been 96
quietly replace q307 = "96" if q307 == "12"

* iteration 1

quietly replace q307 = "A" if q307 == "10"
quietly replace q307 = "B" if q307 == "11"
quietly replace q307 = "C" if q307 == "12"
quietly replace q307 = "D" if q307 == "96"

g q307i=q307
quietly replace q307i= substr(q307i,1,1)

g x307 = q307

* iteration 2

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "A96" if x == "1096"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307ii=x
quietly replace q307ii= substr(x,1,1)

* iteration 3

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "A1112" if x == "101112"
quietly replace x = "A11" if x == "1011"
quietly replace x = "A1196" if x == "101196"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307iii=x
quietly replace q307iii= substr(x,1,1)
 	
* iteration 4

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "BC" if x == "1112"
quietly replace x = "AD" if x == "1096"
quietly replace x = "BDA1196" if x == "1196"
quietly replace x = "AB" if x == "1011"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307iv=x
quietly replace q307iv= substr(x,1,1)

* iteration 5

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1
*NONE

g q307v=x
quietly replace q307v= substr(x,1,1)

* iteration 6

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1
*NONE

g q307vi=x
quietly replace q307vi= substr(x,1,1)

* iteration 7

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "BD" if x == "1196"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307vii=x
quietly replace q307vii= substr(x,1,1)

* iteration 8

quietly replace x= substr(x,2,.)

* check
* list q307 q307i q307ii q307iii q307iv q307v  q307vi q307vii x if q307!="."

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "AC" if x == "1012"
	
*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307viii=x
quietly replace q307viii= substr(x,1,1)

* iteration 9

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "AC" if x == "1012"
		
*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307ix=x
quietly replace q307ix= substr(x,1,1)
		
* iteration 10

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

quietly replace x = "AB" if x == "1011"
quietly replace x = "BC" if x == "1112"
		
*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307x=x
quietly replace q307x= substr(x,1,1)
		
* iteration 11

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307xi=x
quietly replace q307xi= substr(x,1,1)
		
* iteration 12

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1

g q307xii=x
quietly replace q307xii= substr(x,1,1)
		
* iteration 13

quietly replace x= substr(x,2,.)

quietly replace x = "A" if x == "10"
quietly replace x = "B" if x == "11"
quietly replace x = "C" if x == "12"
quietly replace x = "D" if x == "96"

*check if there are any other ambiguities:
list x if regexm(x,"^96")==1| regexm(x,"^12")==1| regexm(x,"^10")==1 | regexm(x,"^11")==1


* quietly replace A,B,C,D, with 10,11,12,96

foreach x of varlist q307 q307i q307ii q307iii q307iv q307v  q307vi q307vii q307viii q307ix q307x q307xi q307xii {
quietly replace `x' = "10" if `x' == "A"
quietly replace `x' = "11" if `x' == "B"
quietly replace `x' = "12" if `x' == "C"
quietly replace `x' = "96" if `x' == "D"
}

* check
*list q307 q307i q307ii q307iii q307iv q307v  q307vi q307vii q307viii q307ix q307x q307xi q307xii x if x=="."
*list q307 q307i q307ii q307iii q307iv q307v  q307vi q307vii q307viii q307ix q307x q307xi q307xii x if q307!="."
* ok!

drop x

*sort
foreach y of varlist   q307i- q307xii{
move `y'  q308
}

*label
foreach y of varlist q307i- q307xii{
label var `y' "mentioned symptoms at last malaria"
}

drop q307

***********
* fix 309 *
***********

* code 'other' as Y
* capitalize all
* split into 2 variables
* code Y as 'other'

quietly replace q309= "Y" in 3110

foreach x of varlist q309{
quietly replace `x'= upper(`x')
}

g q309i=q309
g q309ii=q309

tostring  q309i q309ii, replace

foreach x of varlist q309i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q309ii{
quietly replace `x'= substr(`x',2,1)
}

* to check you can use:
* list q309 q309i q309ii if  q309!="." & q309!="" 
* ok!

*sort
foreach y of varlist q309i q309ii{
move `y' q311
}

*label
foreach y of varlist q309i q309ii{
label var `y' "mentioned place where treatment was sought"
}

drop q309

quietly replace q309i= "other" in 3110

************
* fix 312a *
************

* one answer is 2345678 but 8 is not possible, so i change it to 234567
quietly replace q312a= 234567 in 2809

g q312ai=q312a
g q312aii=q312a
g q312aiii=q312a
g q312aiv=q312a
g q312av=q312a
g q312avi=q312a
g q312avii=q312a

tostring  q312ai- q312avii, replace

foreach x of varlist q312ai{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q312aii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q312aiii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q312aiv{
quietly replace `x'= substr(`x',4,1)
}

foreach x of varlist q312av{
quietly replace `x'= substr(`x',5,1)
}

foreach x of varlist q312avi{
quietly replace `x'= substr(`x',6,1)
}

foreach x of varlist q312avii{
quietly replace `x'= substr(`x',7,1)
}

* to check you can use:
* list  q312a  q312ai- q312avii if  q312a!=.
* ok!

destring  q312ai- q312avii, replace

*sort
foreach y of varlist q312ai- q312avii{
move `y' q313
}

*label
foreach y of varlist q312ai- q312avii{
label var `y' "mentioned source from which respondent heard/saw messages about ITNs"
}

drop q312a

* q312avi actually was not necessary. drop it
drop q312avi

************
* fix 313a *
************

g q313ai=q313a
g q313aii=q313a
g q313aiii=q313a
g q313aiv=q313a

tostring  q313ai- q313aiv, replace

foreach x of varlist q313ai{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q313aii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q313aiii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q313aiv{
quietly replace `x'= substr(`x',4,1)
}

* to check you can use:
* list  q313a  q313ai- q313aiv if  q313a!=.
* ok!

destring  q313ai- q313aiv, replace

*sort
foreach y of varlist q313ai- q313aiv{
move `y' q315
}

*label
foreach y of varlist q313ai- q313aiv{
label var `y' "mentioned  source from which respondent heard/saw messages on early seeking behavior"
}

drop q313a

************
* fix 315a *
************

g q315ai=q315a
g q315aii=q315a
g q315aiii=q315a
g q315aiv=q315a

tostring  q315ai- q315aiv, replace

foreach x of varlist q315ai{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q315aii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q315aiii{
quietly replace `x'= substr(`x',3,1)
}

foreach x of varlist q315aiv{
quietly replace `x'= substr(`x',4,1)
}

* to check you can use:
* list  q315a  q315ai- q315aiv if  q315a!=.
* ok!

destring  q315ai- q315aiv, replace

*sort
foreach y of varlist q315ai- q315aiv{
move `y' q4011
}

*label
foreach y of varlist q315ai- q315aiv{
label var `y' "mentioned  source from which respondent heard/saw messages on early seeking behavior"
}

drop q315a

**********************************
   
   *
  **
 * *
*  *
*****
   *
   *
   
* PART OF SECTION #4 IS ONLY AIMED FOR HH MEMBERS WITH FEVER SO WE SHOULD APPEND THOSE ANSWERS TO THEM ONLY

* 4.1

foreach x of varlist q4021 q4031 q4051 q405a1 q4061 q4071 q4111 q4121 q4131 q4141 q4151{
quietly replace `x'= . if q4011 != lineno 
}

foreach x of varlist q4041 q407a1{
quietly replace `x'= "." if q4011 != lineno 
}

* 4.2

foreach x of varlist q4022 q4032 q4052 q405a2 q4062 q4072 q4112 q4122 q4132 q4142 q4152{
quietly replace `x'= . if q4012 != lineno 
}

foreach x of varlist q4042 q407a2{
quietly replace `x'= "." if q4012 != lineno 
}

* 4.3

foreach x of varlist q4023 q4033 q4053 q405a3 q4063 q4073 q4113 q4123 q4133 q4143 q4153 {
quietly replace `x'= . if q4013 != lineno 
}

* no observations in  q4043 and q407a3 

* 4.4

foreach x of varlist q4024 q4034 q4054 q405a4 q4064 q4074 q4114 q4124 q4134 q4144 q4154 {
quietly replace `x'= . if q4014 != lineno 
}

* no observations in  q4044 and q407a4 

* at this point we can actually drop q4011 q4012 q4013 q4014

drop q4011 q4012 q4013 q4014

egen q402 = rowtotal (q4021- q4024), missing
egen q403 = rowtotal (q4031- q4034), missing

* q404 is string 
* fix problems with q4041 and q4043
* q4043 and q4044 have no observations and can be dropped
drop q4043 q4044  

* capitalize all

foreach x of varlist q4041 q4042{
quietly replace `x'= upper(`x')
}

* split the strings

g  q4041i= q4041
g  q4041ii= q4041
g  q4041iii= q4041

g  q4042i= q4042
g  q4042ii= q4042
g  q4042iii= q4042

foreach x of varlist q4041i q4042i{
quietly replace `x'= substr(`x',1,1)
}

foreach x of varlist q4041ii q4042ii{
quietly replace `x'= substr(`x',2,1)
}

foreach x of varlist q4041iii q4042iii{
quietly replace `x'= substr(`x',3,1)
}

drop q4041 q4042

* proceed with 405 

egen q405 = rowtotal (q4051- q4054), missing 
egen q405a = rowtotal (q405a1- q405a4), missing 
egen q406 = rowtotal (q4061- q4064), missing 
egen q407 = rowtotal (q4071- q4074), missing

* 407a1-4 are strings 

* drop 407a.3&.4 since they are empty
drop  q407a3 q407a4

* Fix typos in 407a.1&.2

quietly replace  q407a1= "AMOXICILLIN" in  498

quietly replace  q407a1= "PARACETAMOL" in 255
quietly replace  q407a1= "PARACETAMOL" in 258
quietly replace  q407a1= "PARACETAMOL" in 473
quietly replace  q407a1= "PARACETAMOL" in 683
quietly replace  q407a1= "PARACETAMOL" in 3877
quietly replace  q407a1= "PARACETAMOL" in 5169
quietly replace  q407a1= "PARACETAMOL" in 5176

quietly replace  q407a1= "BACTERIA" in 301
quietly replace  q407a1= "METRONIDAZOLE" in 3791
quietly replace  q407a1= "CHLOROQUINE & FANSIDAR" in 3816
quietly replace  q407a1= "ASPIRIN" in 5408
quietly replace  q407a1= "OTHER" in 5286

quietly replace  q407a2= "PARACETAMOL" in 476
quietly replace  q407a2= "PARACETAMOL" in 684

quietly replace  q407a2= "FANSIDAR" in 507
quietly replace  q407a2= "FANSIDAR" in 3788

g q407ai = q407a1 if q407a1!="." & q407a1!=""
quietly replace  q407ai=  q407a2 if q407a2!="." & q407a2!=""
list  q407a1 q407a2 q407ai if  q407ai!="." & q407ai!=""
rename q407ai q407a
drop q407a1 q407a2

* continue after 407a

egen q411 = rowtotal (q4111- q4114), missing
egen q412 = rowtotal (q4121- q4124), missing
egen q413 = rowtotal (q4131- q4134), missing
egen q414 = rowtotal (q4141- q4144), missing
egen q415 = rowtotal (q4151- q4154), missing

*sort
foreach y of varlist q402- q415{
move `y' q500
}

* drop old variables
drop  q4021 - q4154

* re-label
label var  q402 "# days since fever started"
label var  q403 "=1 if hh member sought treatment for fever"

foreach y of varlist q4041i -q4041iii{
label var `y' "mentioned source from which 1st hh member sought treatment for fever"
}

foreach y of varlist q4042i -q4042iii{
label var `y' "mentioned source from which 2nd hh member sought treatment for fever"
}

label var  q405 "# days between hh member's fever started & treatment sought"
label var  q405a "amount spent in past 2 weeks to cure fever of hh member [nakfa]"
label var  q406 "=1 if hh member is still sick with fever"
label var  q407 "=1 if hh member took any drugs for fever during illness"
label var  q407a "type of medicine taken, other than AS+AQ"
label var  q411 "when hh member started taking AS+AQ, wrt fever's starting day"
label var  q412 "# days for which hh member took AS+AQ"
label var  q413 "=1 if hh member purchased the drug"
label var  q414 "amount spent for drug of hh member [nakfa]"
label var  q415 "source from which hh member obtained medicine"

quietly destring _all, replace
save "C:\data\full_dataset_labeled_prepared.dta",  replace

***************************************

*     ***  ***  ***** *
*    *   * *  * *     *
*    *   * ***  ***   *
*    ***** *  * *     *
**** *   * ***  ***** *****

* run do files containing value labels

run label01
run label02
run label03
run label04
run label05
run label06
run label07
run label08
run label09
run label10
run labeladd

* label values using the do files created earlier, taken from CSpro

la val interview_result INTERVIEW_RESULT

la val qh3* QH3
la val qh4* QH4
la val qh8* QH8

la val rh13* RH13
la val rh14* RH14

la val q103* Q103
la val q107* Q107
la val q108* Q108
la val q109* Q109
la val q110* Q110
la val q112* Q112
la val q113* Q113
la val q114* Q114
la val q115* Q115
la val q120* Q120

la val q210* LABE
la val q212* LABG
la val q218* Q218
la val q222* Q222
la val q228* Q228
la val q232* Q232

la val q303* Q303

la val q411* LABF
la val q415* LABH

* now i want to label the yes/no answers

* label all 0/1/98 variables
label define yesnoDK 0 "no" 1 "yes" 98"don't know", modify
la val qh5 qh6 qh9  rh10 rh11 rh15 q102 q106 q111*  q119*  q120 q121  q123 q124 yesnoDK
la val q201- q205 q207*     q215_* q219 q220 q223 q226 q229- q231 yesnoDK
la val q301 q308 q311 q312 q313 q315 q403 q406 q413 yesnoDK
la val q500- q501g q502a- q502g q504a- q504h  q506- q508j  q509a- q509j yesnoDK

* label all 0/1/8 variables
label define yesno8DK 0 "no" 1 "yes" 8 "don't know", modify
la val  q211* q214* q407 yesno8DK

* label units of measure used in section 5
label define units 1 "kg" 2 "grams" 3 "milligrams" 4 "litres" 5 "millilitres" 6 "units"
la val  q501au- q501gu q502au- q502gu q504au- q504hu q508au- q508ju  q509au- q509ju units
 


***************************************

save "C:\data\full_dataset_labeled_prepared.dta",  replace

***************************************
***************************************

*** *   * **
*   **  * * * 
**  * * * *  *
*   *  ** *  *
*** *   * *** 

***************************************
***************************************

log close




